# smollm

[![PyPI - Version](https://img.shields.io/pypi/v/smollm.svg)](https://pypi.org/project/smollm)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/smollm.svg)](https://pypi.org/project/smollm)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install smollm
```

## License

`smollm` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
